Plane and Space Curves
======================

Sage enables computations with curves in affine and projective ambient spaces,
curves over `\CC` as Riemann surfaces, and Jacobians of projective curves.

Curves
------

.. toctree::
   :maxdepth: 1

   sage/schemes/curves/constructor
   sage/schemes/curves/curve
   sage/schemes/curves/affine_curve
   sage/schemes/curves/plane_curve_arrangement
   sage/schemes/curves/projective_curve
   sage/schemes/curves/weighted_projective_curve
   sage/schemes/curves/point
   sage/schemes/curves/closed_point
   sage/schemes/curves/zariski_vankampen

Plane conics
------------

.. toctree::
   :maxdepth: 1

   sage/schemes/plane_conics/constructor
   sage/schemes/plane_conics/con_field
   sage/schemes/plane_conics/con_number_field
   sage/schemes/plane_conics/con_rational_field
   sage/schemes/plane_conics/con_finite_field
   sage/schemes/plane_conics/con_rational_function_field

Plane quartics
--------------

.. toctree::
   :maxdepth: 1

   sage/schemes/plane_quartics/quartic_constructor
   sage/schemes/plane_quartics/quartic_generic

Riemann surfaces
----------------

.. toctree::
   :maxdepth: 1

   sage/schemes/riemann_surfaces/riemann_surface

Jacobians
---------

.. toctree::
   :maxdepth: 1

   sage/schemes/jacobians/abstract_jacobian

.. include:: ../footer.txt
